# Methods

As described in [Triggers](./cattle_drive.md#triggers), most user actions with `cattle_grid` can be described as executing a method.
This document describes the methods implemented in `cattle_grid`
additional methods can be implemented through [Extensions](./extensions/index.md).
